==> gspiceui-v0.8.90.tar.gz: gspiceui-v0.8.90/src/ngspice/DlgSrcCfg.hpp <==
//*****************************************************************************
//                                 DlgSrcCfg.hpp                              *
//                                ---------------                             *
//  Description : This dialogue is used to enter values associated with an    *
//                Ng-Spice independent voltage source definition. It is used  *
//                for Transient analysis and is based on a pulse function.    *
//  Started     : 10/05/2005                                                  *
//  Last Update : 24/08/2006                                                  *
//  Copyright   : (C) 2005 by M.S.Waters                                      *
//  Email       : M.Waters@bom.gov.au                                         *
//*****************************************************************************

//*****************************************************************************
//                                                                            *
//    This program is free software; you can redistribute it and/or modify    *
//    it under the terms of the GNU General Public License as published by    *
//    the Free Software Foundation; either version 2 of the License, or       *
//    (at your option) any later version.                                     *
//                                                                            *
//*****************************************************************************

#ifndef DLGSRCCFG_HPP
#define DLGSRCCFG_HPP

// System Includes

#include <iostream>
#include <climits>

// wxWidgets Includes

#include <wx/wx.h>
#include <wx/dialog.h>
#include <wx/choice.h>
#include <wx/tokenzr.h>

// Application Includes

#include "utility/PnlValue.hpp"

// Local Constant Declarations


//*****************************************************************************

class DlgSrcCfg : public wxDialog
{
  private:

    // Value panel controls
    PnlValue  m_oPnlInitV;
    PnlValue  m_oPnlPulseV;
    PnlValue  m_oPnlDelay;
    PnlValue  m_oPnlRise;
    PnlValue  m_oPnlWidth;
    PnlValue  m_oPnlFall;
    PnlValue  m_oPnlPeriod;

    // Button controls
    wxButton  m_oBtnOk;
    wxButton  m_oBtnCancel;

    // Generator command string
    wxString  m_osSrcCmd;

    // Object initialization functions
    void  Initialize( void );
    void  DoLayout( void );

    PnlValue & roGetPanel( int iPnlID );

    void  SetValues( void );
    void  GetValues( void );

    bool  bValidate( void );

  public:

    DlgSrcCfg( wxWindow * poWin );
    ~DlgSrcCfg( );

    bool  bClear( void );

    bool  bEnablePanel( int iPnlID, bool bState ); 
    bool  bSetValue   ( int iPnlID, float fValue,
                        const wxString & rosUnits=wxT("") );
    bool  bSetDefaults( void );

               bool    bSetSrcCmd( const wxString & rosCmd );
    const wxString & rosGetSrcCmd( void );

    // Event handlers
    void  OnBtnOk    ( wxCommandEvent & roEvtCmd );
    void  OnBtnCancel( wxCommandEvent & roEvtCmd );

    // In order to be able to react to a menu command, it must be given a
    // unique identifier such as a const or an enum.
    enum eDlgItemID
    {
      ID_PNL_INITV = 0,
      ID_PNL_PULSEV,
      ID_PNL_DELAY,
      ID_PNL_RISE,
      ID_PNL_WIDTH,
      ID_PNL_FALL,
      ID_PNL_PERIOD,

      ID_BTN_OK,
      ID_BTN_CANCEL,

      ID_UNUSED,      // Assigned to controls for which events are not used

      ID_PNL_FST = ID_PNL_INITV,
      ID_PNL_LST = ID_PNL_PERIOD,

      ID_FST = ID_PNL_INITV,
      ID_LST = ID_BTN_CANCEL
    };

  private:

    // Temporary storage for original spin control values until Ok pressed
    double  m_dfPnlValue[ ID_PNL_LST+1 ];

  public:

    // Leave this as the last line as private access is envoked by macro
    DECLARE_EVENT_TABLE( )
};

//*****************************************************************************

#endif // DLGSRCCFG_HPP

==> gspiceui-v0.9.33.tar.gz: gspiceui-v0.9.33/src/ngspice/DlgSrcCfg.hpp <==
//*****************************************************************************
//                                 DlgSrcCfg.hpp                              *
//                                ---------------                             *
//  Description : This dialogue is used to enter values associated with an    *
//                Ng-Spice independent voltage source definition. It is used  *
//                for Transient analysis and is based on a pulse function.    *
//  Started     : 10/05/2005                                                  *
//  Last Update : 28/06/2007                                                  *
//  Copyright   : (C) 2005 by M.S.Waters                                      *
//  Email       : M.Waters@bom.gov.au                                         *
//*****************************************************************************

//*****************************************************************************
//                                                                            *
//    This program is free software; you can redistribute it and/or modify    *
//    it under the terms of the GNU General Public License as published by    *
//    the Free Software Foundation; either version 2 of the License, or       *
//    (at your option) any later version.                                     *
//                                                                            *
//*****************************************************************************

#ifndef DLGSRCCFG_HPP
#define DLGSRCCFG_HPP

// System Includes

#include <iostream>
#include <climits>

// wxWidgets Includes

#include <wx/wx.h>
#include <wx/tokenzr.h>

// Application Includes

#include "utility/PnlValue.hpp"

// Local Constant Declarations


//*****************************************************************************

class DlgSrcCfg : public wxDialog
{
  private:

    // Value panel controls for a sinusoidal source
    PnlValue  m_oPnlSinOffset;
    PnlValue  m_oPnlSinAmp;
    PnlValue  m_oPnlSinFreq;
    PnlValue  m_oPnlSinDelay;
    PnlValue  m_oPnlSinDamp;

    // Value panel controls for a pulse source
    PnlValue  m_oPnlPulInitV;
    PnlValue  m_oPnlPulMaxV;
    PnlValue  m_oPnlPulDelay;
    PnlValue  m_oPnlPulRise;
    PnlValue  m_oPnlPulWidth;
    PnlValue  m_oPnlPulFall;
    PnlValue  m_oPnlPulPeriod;

    // Button controls
    wxButton  m_oBtnOk;
    wxButton  m_oBtnCancel;

    // Generator command string
    wxString  m_osSrcCmd;

    // Object initialization functions
    void  Initialize( void );
    void  Create    ( void );
    void  ToolTips  ( void );
    void  DoLayout  ( void );

    PnlValue & roGetPanel( int iPnlID );

    void  SetValues( void );
    void  GetValues( void );

    bool  bValidate( void );

  public:

    DlgSrcCfg( wxWindow * poWin );
   ~DlgSrcCfg( );

    bool  bClear( void );
    bool  bEnablePanel( int iPnlID, bool bState ); 

    bool     bSetDefaults( void );
    bool     bSetValue   ( int iPnlID, float fValue,
                          const wxString & rosUnits=wxT("") );
    double  dfGetValue   ( int iPnlID )
                              { return( roGetPanel( iPnlID ).dfGetValue( ) ); }

               bool    bSetSrcCmd( const wxString & rosCmd );
    const wxString & rosGetSrcCmd( void );

    // Event handlers
    void  OnBtnOk    ( wxCommandEvent & roEvtCmd );
    void  OnBtnCancel( wxCommandEvent & roEvtCmd );

    // In order to be able to react to a menu command, it must be given a
    // unique identifier such as a const or an enum.
    enum eDlgItemID
    {
      ID_PNL_SIN_OFFSET = 0,
      ID_PNL_SIN_AMP,
      ID_PNL_SIN_FREQ,
      ID_PNL_SIN_DELAY,
      ID_PNL_SIN_DAMP,

      ID_PNL_PUL_INITV,
      ID_PNL_PUL_MAXV,
      ID_PNL_PUL_DELAY,
      ID_PNL_PUL_RISE,
      ID_PNL_PUL_WIDTH,
      ID_PNL_PUL_FALL,
      ID_PNL_PUL_PERIOD,

      ID_BTN_OK,
      ID_BTN_CANCEL,

      ID_UNUSED,      // Assigned to controls for which events are not used

      ID_PNL_FST = ID_PNL_SIN_OFFSET,
      ID_PNL_LST = ID_PNL_PUL_PERIOD,

      ID_FST = ID_PNL_SIN_OFFSET,
      ID_LST = ID_BTN_CANCEL
    };

  private:

    // Temporary storage for original spin control values until Ok pressed
    double  m_dfPnlValue[ ID_PNL_LST+1 ];

  public:

    // Leave this as the last line as private access is envoked by macro
    DECLARE_EVENT_TABLE( )
};

//*****************************************************************************

#endif // DLGSRCCFG_HPP
